package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Oct 24, 2023
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SubscribeRequest struct {
Email string `json:"email"`
}
type SubscribeRequestBody struct {
Email string `json:"email_address"`
Status string `json:"status"`
Tags []string `json:"tags"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.